#[non_exhaustive]pub struct OptionsGreeks {
pub delta: Option<f64>,
pub gamma: Option<f64>,
pub theta: Option<f64>,
pub vega: Option<f64>,
}Expand description
Greeks for an options contract snapshot.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delta: Option<f64>Delta: rate of change of the option price with respect to the underlying.
gamma: Option<f64>Gamma: rate of change of delta with respect to the underlying.
theta: Option<f64>Theta: rate of change of the option price with respect to time.
vega: Option<f64>Vega: rate of change of the option price with respect to volatility.