Module alphavantage

Module alphavantage 

Alpha Vantage configuration (requires the alphavantage feature).

Call init before constructing a provider when the API key should come from application configuration instead of the process environment.

Functions

init
Initialize the global Alpha Vantage client with an API key.
init_with_timeout
Initialize the Alpha Vantage client with a custom timeout.