pub fn held_for_bars(min_bars: usize) -> HeldForBarsExpand description
Create a condition that checks if position has been held for at least N bars.
pub fn held_for_bars(min_bars: usize) -> HeldForBarsCreate a condition that checks if position has been held for at least N bars.