pub struct CrossesAbove<R: IndicatorRef> { /* private fields */ }Expand description
Condition: indicator crosses above a threshold.
True when the previous value was at or below the threshold and the current value is above it.
Implementations
Sourceimpl<R: IndicatorRef> CrossesAbove<R>
impl<R: IndicatorRef> CrossesAbove<R>