pub struct CrossesAboveRef<R1: IndicatorRef, R2: IndicatorRef> { /* private fields */ }Expand description
Condition: indicator crosses above another indicator.
True when the fast indicator was at or below the slow indicator and is now above it.
Implementations
Sourceimpl<R1: IndicatorRef, R2: IndicatorRef> CrossesAboveRef<R1, R2>
impl<R1: IndicatorRef, R2: IndicatorRef> CrossesAboveRef<R1, R2>