pub struct HeldForBars {
pub min_bars: usize,
}Expand description
Condition: position has been held for at least N bars.
Fields
min_bars: usizeMinimum number of bars the position must be held
Implementations