#[non_exhaustive]pub struct SymbolData {
pub symbol: String,
pub candles: Vec<Candle>,
pub dividends: Vec<Dividend>,
}Expand description
Input data for a single symbol in the portfolio backtest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.symbol: StringTicker symbol (e.g. "AAPL")
candles: Vec<Candle>OHLCV candles sorted by timestamp ascending.
dividends: Vec<Dividend>Dividend history sorted by timestamp ascending.
An empty vec disables dividend processing for this symbol.
Implementations