pub struct StrategyBuilder<E = (), X = ()> { /* private fields */ }Expand description
Builder for creating custom strategies with entry/exit conditions.
The builder enforces that both entry and exit conditions are provided before a strategy can be built.
Implementations
Sourceimpl StrategyBuilder<(), ()>
impl StrategyBuilder<(), ()>
Sourceimpl<X> StrategyBuilder<(), X>
impl<X> StrategyBuilder<(), X>
Sourceimpl<E> StrategyBuilder<E, ()>
impl<E> StrategyBuilder<E, ()>
Sourceimpl<E: Condition, X: Condition> StrategyBuilder<E, X>
impl<E: Condition, X: Condition> StrategyBuilder<E, X>
Sourcepub fn with_short<SE: Condition, SX: Condition>(
self,
entry: SE,
exit: SX,
) -> Self
pub fn with_short<SE: Condition, SX: Condition>( self, entry: SE, exit: SX, ) -> Self
Sourcepub fn build(self) -> CustomStrategy<E, X>
pub fn build(self) -> CustomStrategy<E, X>