#[non_exhaustive]pub struct ProtocolTvl {
pub slug: String,
pub name: Option<String>,
pub symbol: Option<String>,
pub url: Option<String>,
pub chains: Vec<String>,
pub tvl: Option<f64>,
pub tvl_by_chain: Vec<ChainAllocation>,
pub change_1d_percent: Option<f64>,
pub change_7d_percent: Option<f64>,
pub market_cap: Option<f64>,
}Expand description
Total value locked in a DeFi protocol, with the metadata needed to identify it.
Obtain via CryptoCoin::tvl.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.slug: StringDefiLlama protocol slug, as queried (e.g. "aave").
name: Option<String>Display name (e.g. "AAVE").
symbol: Option<String>Governance/token symbol, when the protocol has one.
url: Option<String>Project homepage.
chains: Vec<String>Chains the protocol is deployed on.
tvl: Option<f64>Latest total value locked, in USD.
tvl_by_chain: Vec<ChainAllocation>TVL broken down by chain, in USD.
change_1d_percent: Option<f64>Change in TVL over the last day, as a percentage.
change_7d_percent: Option<f64>Change in TVL over the last seven days, as a percentage.
market_cap: Option<f64>Market capitalisation of the protocol’s token, in USD.