pub fn init(email: impl Into<String>) -> Result<()>Expand description
Initialize the global EDGAR client with a contact email.
This function must be called once before using any EDGAR functions. The SEC requires all automated requests to include a User-Agent header with a contact email address.
Arguments
email- Contact email address (included in User-Agent header)
Example
use finance_query::edgar;
edgar::init("user@example.com")?;Errors
Returns an error if EDGAR has already been initialized.