ExchangeCode

Enum ExchangeCode 

#[non_exhaustive]
pub enum ExchangeCode {
Show 20 variants Ase, Bts, Ncm, Ngm, Nms, Nyq, Pcx, Pnk, Nas, Asx, Bse, Hkg, Krx, Lse, Nsi, Shh, Shz, Tyo, Tor, Ger,
}
Typed exchange code for screener queries.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Ase

NYSE American / AMEX (“ASE”)



Bts

OTC Bulletin Board (“BTS”)



Ncm

NASDAQ Capital Market (“NCM”)



Ngm

NASDAQ Global Market (“NGM”)



Nms

NASDAQ Global Select Market (“NMS”) — primary NASDAQ tier



Nyq

New York Stock Exchange (“NYQ”)



Pcx

NYSE Arca (“PCX”)



Pnk

OTC Pink Sheets / OTC Markets (“PNK”)



Nas

NASDAQ — used for US mutual funds (“NAS”)



Asx

Australian Securities Exchange (“ASX”)



Bse

Bombay Stock Exchange (“BSE”)



Hkg

Hong Kong Stock Exchange (“HKG”)



Krx

Korea Exchange (“KRX”)



Lse

London Stock Exchange (“LSE”)



Nsi

National Stock Exchange of India (“NSI”)



Shh

Shanghai Stock Exchange (“SHH”)



Shz

Shenzhen Stock Exchange (“SHZ”)



Tyo

Tokyo Stock Exchange (“TYO”)



Tor

Toronto Stock Exchange (“TOR”)



Ger

XETRA / Deutsche Börse (“GER”)

Implementations

Source

impl ExchangeCode

pub fn as_str(self) -> &'static str

Returns the exchange code string used by Yahoo Finance.