ScreenerPeerGroup

Enum ScreenerPeerGroup 

#[non_exhaustive]
pub enum ScreenerPeerGroup {
Show 86 variants Semiconductors, SemiconductorEquipment, SoftwareAndServices, TechnologyHardwareAndEquipment, InternetCompanies, ElectronicEquipment, Banks, DiversifiedBanks, RegionalBanks, CapitalMarkets, Insurance, LifeAndHealthInsurance, PropertyAndCasualtyInsurance, AssetManagement, ConsumerFinance, MortgageFinance, SpecialtyFinance, DiversifiedFinancialServices, InvestmentBankingAndBrokerage, Pharmaceuticals, Biotechnology, HealthCareEquipment, HealthCareServices, HealthCareFacilities, ManagedHealthcare, Automobiles, AutoComponents, FoodProducts, PackagedFoodsAndMeats, Beverages, HouseholdProducts, HouseholdDurables, PersonalProducts, ApparelAndLuxuryGoods, Retailers, FoodAndDrugRetailing, GeneralMerchandiseStores, SpecialtyRetail, LeisureProducts, Hotels, Restaurants, Media, DrugRetail, IntegratedOilAndGas, OilAndGasExplorationAndProduction, OilAndGasRefiningAndMarketing, OilAndGasStorageAndTransportation, EnergyEquipmentAndServices, AerospaceAndDefense, Airlines, IndustrialMachinery, IndustrialConglomerates, IndustrialGases, BuildingProducts, Chemicals, SpecialtyChemicals, MetalsAndMining, PaperAndForestProducts, ContainersAndPackaging, CommercialServicesAndSupplies, Railroads, Trucking, ResearchAndConsultingServices, HumanResourceAndEmploymentServices, DataProcessingAndOutsourcedServices, ItConsultingAndOtherServices, RealEstate, RetailReits, ElectricUtilities, GasUtilities, WaterUtilities, MultiUtilities, RenewableElectricity, TelecomServices, WirelessTelecommunicationServices, Steel, Gold, OilAndGas, WasteManagement, Tobacco, OfficeElectronics, CommunicationsEquipment, HomeBuilding, HomeFurnishings, HouseholdAppliances, Publishing,
}
Equity peer group for screener queries.

Use with EquityField::PeerGroup and ScreenerFieldExt::eq_str.

These are Yahoo Finance’s proprietary peer group classifications used to group stocks for comparison purposes. Values are broader than Industry names.

Example

use finance_query::{EquityField, EquityScreenerQuery, ScreenerFieldExt, ScreenerPeerGroup};

let query = EquityScreenerQuery::new()
    .add_condition(EquityField::PeerGroup.eq_str(ScreenerPeerGroup::Semiconductors));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Semiconductors

“Semiconductors”



SemiconductorEquipment

“Semiconductor Equipment”



SoftwareAndServices

“Software & Services”



TechnologyHardwareAndEquipment

“Technology Hardware & Equipment”



InternetCompanies

“Internet Companies”



ElectronicEquipment

“Electronic Equipment”



Banks

“Banks”



DiversifiedBanks

“Diversified Banks”



RegionalBanks

“Regional Banks”



CapitalMarkets

“Capital Markets”



Insurance

“Insurance”



LifeAndHealthInsurance

“Life & Health Insurance”



PropertyAndCasualtyInsurance

“Property & Casualty Insurance”



AssetManagement

“Asset Management”



ConsumerFinance

“Consumer Finance”



MortgageFinance

“Mortgage Finance”



SpecialtyFinance

“Specialty Finance”



DiversifiedFinancialServices

“Diversified Financial Services”



InvestmentBankingAndBrokerage

“Investment Banking & Brokerage”



Pharmaceuticals

“Pharmaceuticals”



Biotechnology

“Biotechnology”



HealthCareEquipment

“Health Care Equipment”



HealthCareServices

“Health Care Services”



HealthCareFacilities

“Health Care Facilities”



ManagedHealthcare

“Managed Healthcare”



Automobiles

“Automobiles”



AutoComponents

“Auto Components”



FoodProducts

“Food Products”



PackagedFoodsAndMeats

“Packaged Foods & Meats”



Beverages

“Beverages”



HouseholdProducts

“Household Products”



HouseholdDurables

“Household Durables”



PersonalProducts

“Personal Products”



ApparelAndLuxuryGoods

“Apparel & Luxury Goods”



Retailers

“Retailers”



FoodAndDrugRetailing

“Food & Drug Retailing”



GeneralMerchandiseStores

“General Merchandise Stores”



SpecialtyRetail

“Specialty Retail”



LeisureProducts

“Leisure Products”



Hotels

“Hotels”



Restaurants

“Restaurants”



Media

“Media”



DrugRetail

“Drug Retail”



IntegratedOilAndGas

“Integrated Oil & Gas”



OilAndGasExplorationAndProduction

“Oil & Gas Exploration & Production”



OilAndGasRefiningAndMarketing

“Oil & Gas Refining & Marketing”



OilAndGasStorageAndTransportation

“Oil & Gas Storage & Transportation”



EnergyEquipmentAndServices

“Energy Equipment & Services”



AerospaceAndDefense

“Aerospace & Defense”



Airlines

“Airlines”



IndustrialMachinery

“Industrial Machinery”



IndustrialConglomerates

“Industrial Conglomerates”



IndustrialGases

“Industrial Gases”



BuildingProducts

“Building Products”



Chemicals

“Chemicals”



SpecialtyChemicals

“Specialty Chemicals”



MetalsAndMining

“Metals & Mining”



PaperAndForestProducts

“Paper & Forest Products”



ContainersAndPackaging

“Containers & Packaging”



CommercialServicesAndSupplies

“Commercial Services & Supplies”



Railroads

“Railroads”



Trucking

“Trucking”



ResearchAndConsultingServices

“Research & Consulting Services”



HumanResourceAndEmploymentServices

“Human Resource & Employment Services”



DataProcessingAndOutsourcedServices

“Data Processing & Outsourced Services”



ItConsultingAndOtherServices

“IT Consulting & Other Services”



RealEstate

“Real Estate”



RetailReits

“Retail REITs”



ElectricUtilities

“Electric Utilities”



GasUtilities

“Gas Utilities”



WaterUtilities

“Water Utilities”



MultiUtilities

“Multi-Utilities”



RenewableElectricity

“Renewable Electricity”



TelecomServices

“Telecom Services”



WirelessTelecommunicationServices

“Wireless Telecommunication Services”



Steel

“Steel”



Gold

“Gold”



OilAndGas

“Oil & Gas”



WasteManagement

“Waste Management”



Tobacco

“Tobacco”



OfficeElectronics

“Office Electronics”



CommunicationsEquipment

“Communications Equipment”



HomeBuilding

“Home Building”



HomeFurnishings

“Home Furnishings”



HouseholdAppliances

“Household Appliances”



Publishing

“Publishing”

Implementations

Source

impl ScreenerPeerGroup

pub fn as_str(self) -> &'static str

Returns the peer group name used by Yahoo Finance.