Module finance

Module finance 

Non-symbol-specific operations (search, lookup, screeners, market data, etc.). Non-symbol-specific Yahoo Finance operations

This module provides functions for operations that don’t require a specific stock symbol, such as searching for symbols and fetching screener data.

Structs

AnalystEstimate
An analyst estimate entry (revenue, EBITDA, EPS forecasts).
AnalystRecommendation
An analyst stock recommendation (buy/hold/sell counts).
EarningsCalendarEntry
An upcoming earnings calendar entry.
InsiderTransaction
An insider trading transaction record.
IpoCalendarEntry
An upcoming IPO calendar entry.
LookupOptions
Lookup configuration options
SearchOptions
Search configuration options

Enums

LookupType
Asset types available for lookup
Period
Time period for analyst estimates.

Functions

analyst_estimates
Fetch analyst estimates for a symbol.
analyst_recommendations
Fetch analyst stock recommendations for a symbol.
currencies
Get list of available currencies
custom_screener
Execute a custom screener query
earnings_calendar
Fetch the upcoming earnings calendar (market-wide, not symbol-filtered).
earnings_transcript
Get earnings transcript for a symbol
earnings_transcripts
Get all earnings transcripts for a symbol
exchanges
Get list of supported exchanges
fear_and_greed
Fetch the current CNN Fear & Greed Index from Alternative.me.
hours
Get market hours/status
indices
Get world market indices quotes
industry
Fetch detailed industry data from Yahoo Finance
insider_trading
Fetch insider trading transactions for a symbol.
ipo_calendar
Fetch the upcoming IPO calendar (market-wide, not symbol-filtered).
lookup
Look up symbols by type (equity, ETF, mutual fund, index, future, currency, cryptocurrency)
market_summary
Get market summary
news
Get general market news
screener
Fetch data from a predefined Yahoo Finance screener
search
Search for stock symbols and companies
sector
Fetch detailed sector data from Yahoo Finance
symbol_sentiment
Fetch sentiment analysis for a symbol based on recent Polygon.io news.
trending
Get trending tickers for a region