Module summary

Module summary 

Indicators summary module.

Provides the IndicatorsSummary type which calculates and returns the latest values for all 52+ technical indicators at once.

This module reuses the main indicator implementations and extracts the last value, ensuring consistency and eliminating code duplication.

Structs

AroonData
Aroon indicator data
BollingerBandsData
Bollinger Bands data
BullBearPowerData
Bull Bear Power indicator data
DonchianChannelsData
Donchian Channels data
ElderRayData
Elder Ray Index data
IchimokuData
Ichimoku Cloud data
IndicatorsSummary
Summary of all calculated technical indicators
KeltnerChannelsData
Keltner Channels data
MacdData
MACD indicator data
StochasticData
Stochastic Oscillator data
SuperTrendData
SuperTrend indicator data