Module quote

Module quote 

Yahoo quoteSummary module types carried by QuoteSummaryResponse.

A QuoteProvider implementation populates these; they are also what Ticker::price, Ticker::asset_profile and the other module accessors return.

Structs

AssetProfile
Company asset profile and information
CalendarEvents
Calendar events including earnings and dividend dates
CompanyOfficer
Company officer information
DefaultKeyStatistics
Default key statistics for a symbol
Earnings
Earnings data including charts and forecasts
EarningsHistory
Historical earnings data
EarningsTrend
Earnings trend and estimates
EquityPerformance
Equity performance data comparing stock returns to benchmark
FinancialData
Financial data and key metrics
FundOwnership
Fund ownership data
FundPerformance
Fund performance data including returns, risk metrics, and historical performance
FundProfile
Fund profile information including management, fees, and expenses
IndexTrend
Index trend data (growth estimates for the index)
IndustryTrend
Industry trend data
InsiderHolders
Insider holders data
InsiderTransactions
Insider transaction history
InstitutionOwnership
Institutional ownership data
MajorHoldersBreakdown
Breakdown of ownership by different types of holders
NetSharePurchaseActivity
Net share purchase activity by insiders
Price
Detailed pricing data for a stock
QuoteTypeData
Quote type metadata for a symbol (used in quoteSummary module)
RecommendationTrend
Analyst recommendation trends
SecFilings
SEC filings data
SectorTrend
Sector trend data
SummaryDetail
Summary detail trading and valuation metrics
SummaryProfile
Company profile information
TopHoldings
Fund holdings including asset allocation, top holdings, and sector weightings
UpgradeDowngradeHistory
Analyst upgrade/downgrade history