#[non_exhaustive]pub struct DefaultKeyStatistics<F: Format = Both> {Show 61 fields
pub week_52_change: Option<F::Value<f64>>,
pub sand_p_52_week_change: Option<F::Value<f64>>,
pub annual_holdings_turnover: Option<Value>,
pub annual_report_expense_ratio: Option<Value>,
pub beta: Option<F::Value<f64>>,
pub beta3_year: Option<Value>,
pub book_value: Option<F::Value<f64>>,
pub category: Option<String>,
pub date_short_interest: Option<F::Value<i64>>,
pub earnings_quarterly_growth: Option<F::Value<f64>>,
pub enterprise_to_ebitda: Option<F::Value<f64>>,
pub enterprise_to_revenue: Option<F::Value<f64>>,
pub enterprise_value: Option<F::Value<i64>>,
pub five_year_average_return: Option<Value>,
pub float_shares: Option<F::Value<i64>>,
pub forward_eps: Option<F::Value<f64>>,
pub forward_pe: Option<F::Value<f64>>,
pub fund_family: Option<String>,
pub fund_inception_date: Option<Value>,
pub funding_to_date: Option<Value>,
pub held_percent_insiders: Option<F::Value<f64>>,
pub held_percent_institutions: Option<F::Value<f64>>,
pub implied_shares_outstanding: Option<F::Value<i64>>,
pub last_cap_gain: Option<Value>,
pub last_dividend_date: Option<F::Value<i64>>,
pub last_dividend_value: Option<F::Value<f64>>,
pub last_fiscal_year_end: Option<F::Value<i64>>,
pub last_split_date: Option<F::Value<i64>>,
pub last_split_factor: Option<String>,
pub latest_amount_raised: Option<Value>,
pub latest_funding_date: Option<Value>,
pub latest_implied_valuation: Option<Value>,
pub latest_share_class: Option<String>,
pub lead_investor: Option<String>,
pub legal_type: Option<String>,
pub max_age: Option<i64>,
pub morning_star_overall_rating: Option<Value>,
pub morning_star_risk_rating: Option<Value>,
pub most_recent_quarter: Option<F::Value<i64>>,
pub net_income_to_common: Option<F::Value<i64>>,
pub next_fiscal_year_end: Option<F::Value<i64>>,
pub peg_ratio: Option<Value>,
pub price_hint: Option<F::Value<i64>>,
pub price_to_book: Option<F::Value<f64>>,
pub price_to_sales_trailing12_months: Option<Value>,
pub profit_margins: Option<F::Value<f64>>,
pub qtd_return: Option<Value>,
pub revenue_quarterly_growth: Option<Value>,
pub shares_outstanding: Option<F::Value<i64>>,
pub shares_percent_shares_out: Option<F::Value<f64>>,
pub shares_short: Option<F::Value<i64>>,
pub shares_short_previous_month_date: Option<F::Value<i64>>,
pub shares_short_prior_month: Option<F::Value<i64>>,
pub short_percent_of_float: Option<F::Value<f64>>,
pub short_ratio: Option<F::Value<f64>>,
pub three_year_average_return: Option<Value>,
pub total_assets: Option<Value>,
pub total_funding_rounds: Option<Value>,
pub trailing_eps: Option<F::Value<f64>>,
pub yield_value: Option<Value>,
pub ytd_return: Option<Value>,
}Expand description
Default key statistics for a symbol
Contains extensive statistical data including valuation metrics, share data, and financial ratios.
The type parameter F controls how numeric fields are represented:
DefaultKeyStatistics/DefaultKeyStatistics<Both>— default; fields holdFormattedValue<T>DefaultKeyStatistics<Raw>— fields holdTdirectly (e.g.Option<f64>)DefaultKeyStatistics<Pretty>— fields holdOption<String>(human-readable)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.week_52_change: Option<F::Value<f64>>52-week price change percentage
sand_p_52_week_change: Option<F::Value<f64>>S&P 500 52-week change percentage
annual_holdings_turnover: Option<Value>Annual holdings turnover (for funds)
annual_report_expense_ratio: Option<Value>Annual report expense ratio (for funds)
beta: Option<F::Value<f64>>Beta coefficient (volatility vs market)
beta3_year: Option<Value>3-year beta (for funds)
book_value: Option<F::Value<f64>>Book value per share
category: Option<String>Fund category
date_short_interest: Option<F::Value<i64>>Date of short interest data
earnings_quarterly_growth: Option<F::Value<f64>>Quarterly earnings growth rate
enterprise_to_ebitda: Option<F::Value<f64>>Enterprise value to EBITDA ratio
enterprise_to_revenue: Option<F::Value<f64>>Enterprise value to revenue ratio
enterprise_value: Option<F::Value<i64>>Total enterprise value
five_year_average_return: Option<Value>5-year average return (for funds)
Number of floating shares
forward_eps: Option<F::Value<f64>>Forward earnings per share
forward_pe: Option<F::Value<f64>>Forward price-to-earnings ratio
fund_family: Option<String>Fund family name
fund_inception_date: Option<Value>Fund inception date
funding_to_date: Option<Value>Funding to date (for private companies)
held_percent_insiders: Option<F::Value<f64>>Percentage of shares held by insiders
held_percent_institutions: Option<F::Value<f64>>Percentage of shares held by institutions
Implied shares outstanding
last_cap_gain: Option<Value>Last capital gain (for funds)
last_dividend_date: Option<F::Value<i64>>Last dividend date
last_dividend_value: Option<F::Value<f64>>Last dividend value per share
last_fiscal_year_end: Option<F::Value<i64>>Last fiscal year end date
last_split_date: Option<F::Value<i64>>Last stock split date
last_split_factor: Option<String>Last stock split factor (e.g., “4:1”)
latest_amount_raised: Option<Value>Latest amount raised (for private companies)
latest_funding_date: Option<Value>Latest funding date (for private companies)
latest_implied_valuation: Option<Value>Latest implied valuation (for private companies)
Latest share class
lead_investor: Option<String>Lead investor (for private companies)
legal_type: Option<String>Legal type
max_age: Option<i64>Maximum age of data in seconds
morning_star_overall_rating: Option<Value>Morningstar overall rating (for funds)
morning_star_risk_rating: Option<Value>Morningstar risk rating (for funds)
most_recent_quarter: Option<F::Value<i64>>Most recent quarter end date
net_income_to_common: Option<F::Value<i64>>Net income to common shareholders
next_fiscal_year_end: Option<F::Value<i64>>Next fiscal year end date
peg_ratio: Option<Value>PEG ratio (Price/Earnings to Growth)
price_hint: Option<F::Value<i64>>Price hint (decimal places)
price_to_book: Option<F::Value<f64>>Price to book ratio
price_to_sales_trailing12_months: Option<Value>Price to sales ratio (trailing 12 months)
profit_margins: Option<F::Value<f64>>Profit margins percentage
qtd_return: Option<Value>Quarter-to-date return (for funds)
revenue_quarterly_growth: Option<Value>Quarterly revenue growth rate
Total shares outstanding
Short interest as percentage of shares outstanding
Number of shares short
Previous month date for short interest
Shares short in prior month
short_percent_of_float: Option<F::Value<f64>>Short interest as percentage of float
short_ratio: Option<F::Value<f64>>Short ratio (days to cover)
three_year_average_return: Option<Value>3-year average return (for funds)
total_assets: Option<Value>Total assets (for funds)
total_funding_rounds: Option<Value>Total funding rounds (for private companies)
trailing_eps: Option<F::Value<f64>>Trailing earnings per share
yield_value: Option<Value>Yield percentage (for bonds/funds)
ytd_return: Option<Value>Year-to-date return (for funds)
Implementations
Sourceimpl DefaultKeyStatistics<Both>
impl DefaultKeyStatistics<Both>
Sourcepub fn into_raw(self) -> DefaultKeyStatistics<Raw>
pub fn into_raw(self) -> DefaultKeyStatistics<Raw>
Convert into a Raw view, extracting .raw from each FormattedValue field.
Sourcepub fn as_raw(&self) -> DefaultKeyStatistics<Raw>
pub fn as_raw(&self) -> DefaultKeyStatistics<Raw>
Clone and convert into a Raw view.
Sourcepub fn into_pretty(self) -> DefaultKeyStatistics<Pretty>
pub fn into_pretty(self) -> DefaultKeyStatistics<Pretty>
Convert into a Pretty view, extracting .fmt from each FormattedValue field.
Sourcepub fn as_pretty(&self) -> DefaultKeyStatistics<Pretty>
pub fn as_pretty(&self) -> DefaultKeyStatistics<Pretty>
Clone and convert into a Pretty view.