SummaryDetail

Struct SummaryDetail 

#[non_exhaustive]
pub struct SummaryDetail<F: Format = Both> {
Show 57 fields pub algorithm: Option<Value>, pub all_time_high: Option<F::Value<f64>>, pub all_time_low: Option<F::Value<f64>>, pub ask: Option<F::Value<f64>>, pub ask_size: Option<F::Value<i64>>, pub average_daily_volume10_day: Option<F::Value<i64>>, pub average_volume: Option<F::Value<i64>>, pub average_volume10days: Option<F::Value<i64>>, pub beta: Option<F::Value<f64>>, pub bid: Option<F::Value<f64>>, pub bid_size: Option<F::Value<i64>>, pub circulating_supply: Option<Value>, pub coin_market_cap_link: Option<Value>, pub currency: Option<String>, pub day_high: Option<F::Value<f64>>, pub day_low: Option<F::Value<f64>>, pub dividend_rate: Option<F::Value<f64>>, pub dividend_yield: Option<F::Value<f64>>, pub ex_dividend_date: Option<F::Value<i64>>, pub expire_date: Option<Value>, pub fifty_day_average: Option<F::Value<f64>>, pub fifty_two_week_high: Option<F::Value<f64>>, pub fifty_two_week_low: Option<F::Value<f64>>, pub five_year_avg_dividend_yield: Option<F::Value<f64>>, pub forward_pe: Option<F::Value<f64>>, pub from_currency: Option<String>, pub last_market: Option<String>, pub market_cap: Option<F::Value<i64>>, pub max_age: Option<i64>, pub max_supply: Option<Value>, pub nav_price: Option<F::Value<f64>>, pub open: Option<F::Value<f64>>, pub open_interest: Option<Value>, pub payout_ratio: Option<F::Value<f64>>, pub previous_close: Option<F::Value<f64>>, pub price_hint: Option<F::Value<i64>>, pub price_to_sales_trailing12_months: Option<F::Value<f64>>, pub qtd_return: Option<Value>, pub regular_market_day_high: Option<F::Value<f64>>, pub regular_market_day_low: Option<F::Value<f64>>, pub regular_market_open: Option<F::Value<f64>>, pub regular_market_previous_close: Option<F::Value<f64>>, pub regular_market_volume: Option<F::Value<i64>>, pub start_date: Option<Value>, pub strike_price: Option<Value>, pub to_currency: Option<String>, pub total_assets: Option<F::Value<i64>>, pub tradeable: Option<bool>, pub trailing_annual_dividend_rate: Option<F::Value<f64>>, pub trailing_annual_dividend_yield: Option<F::Value<f64>>, pub trailing_pe: Option<F::Value<f64>>, pub two_hundred_day_average: Option<F::Value<f64>>, pub volume: Option<F::Value<i64>>, pub volume24_hr: Option<Value>, pub volume_all_currencies: Option<Value>, pub yield_value: Option<F::Value<f64>>, pub ytd_return: Option<Value>,
}
Summary detail trading and valuation metrics

Contains detailed information about price, volume, market cap, and other trading data.

The type parameter F controls how numeric fields are represented:

  • SummaryDetail / SummaryDetail<Both>default; fields hold FormattedValue<T>
  • SummaryDetail<Raw> — fields hold T directly (e.g. Option<f64>)
  • SummaryDetail<Pretty> — fields hold Option<String> (human-readable)

Obtain converted views via Quote::as_raw or call .as_raw() / .into_raw() on a SummaryDetail<Both> directly.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
algorithm: Option<Value>

Algorithm (for crypto/special assets)

all_time_high: Option<F::Value<f64>>

All-time high price

all_time_low: Option<F::Value<f64>>

All-time low price

ask: Option<F::Value<f64>>

Current ask price

ask_size: Option<F::Value<i64>>

Ask size (shares)

average_daily_volume10_day: Option<F::Value<i64>>

Average daily trading volume (10 day)

average_volume: Option<F::Value<i64>>

Average trading volume

average_volume10days: Option<F::Value<i64>>

Average trading volume (10 days)

beta: Option<F::Value<f64>>

Beta coefficient (volatility vs market)

bid: Option<F::Value<f64>>

Current bid price

bid_size: Option<F::Value<i64>>

Bid size (shares)

circulating_supply: Option<Value>

Circulating supply (for crypto)

coin_market_cap_link: Option<Value>

CoinMarketCap link (for crypto)

currency: Option<String>

Currency code

day_high: Option<F::Value<f64>>

Day’s high price

day_low: Option<F::Value<f64>>

Day’s low price

dividend_rate: Option<F::Value<f64>>

Annual dividend rate

dividend_yield: Option<F::Value<f64>>

Dividend yield percentage

ex_dividend_date: Option<F::Value<i64>>

Ex-dividend date

expire_date: Option<Value>

Expiration date (for options/futures)

fifty_day_average: Option<F::Value<f64>>

50-day moving average

fifty_two_week_high: Option<F::Value<f64>>

52-week high price

fifty_two_week_low: Option<F::Value<f64>>

52-week low price

five_year_avg_dividend_yield: Option<F::Value<f64>>

5-year average dividend yield

forward_pe: Option<F::Value<f64>>

Forward price-to-earnings ratio

from_currency: Option<String>

From currency (for currency pairs)

last_market: Option<String>

Last market (for crypto)

market_cap: Option<F::Value<i64>>

Market capitalization

max_age: Option<i64>

Maximum age of data in seconds

max_supply: Option<Value>

Maximum supply (for crypto)

nav_price: Option<F::Value<f64>>

Net asset value price (for funds)

open: Option<F::Value<f64>>

Opening price

open_interest: Option<Value>

Open interest (for options/futures)

payout_ratio: Option<F::Value<f64>>

Dividend payout ratio

previous_close: Option<F::Value<f64>>

Previous closing price

price_hint: Option<F::Value<i64>>

Price hint (decimal places)

price_to_sales_trailing12_months: Option<F::Value<f64>>

Price to sales ratio (trailing 12 months)

qtd_return: Option<Value>

Quarter-to-date return

regular_market_day_high: Option<F::Value<f64>>

Regular market day high

regular_market_day_low: Option<F::Value<f64>>

Regular market day low

regular_market_open: Option<F::Value<f64>>

Regular market opening price

regular_market_previous_close: Option<F::Value<f64>>

Regular market previous close

regular_market_volume: Option<F::Value<i64>>

Regular market trading volume

start_date: Option<Value>

Start date (for funds/special assets)

strike_price: Option<Value>

Strike price (for options)

to_currency: Option<String>

To currency (for currency pairs)

total_assets: Option<F::Value<i64>>

Total assets (for funds)

tradeable: Option<bool>

Whether the security is tradeable

trailing_annual_dividend_rate: Option<F::Value<f64>>

Trailing annual dividend rate

trailing_annual_dividend_yield: Option<F::Value<f64>>

Trailing annual dividend yield

trailing_pe: Option<F::Value<f64>>

Trailing price-to-earnings ratio

two_hundred_day_average: Option<F::Value<f64>>

200-day moving average

volume: Option<F::Value<i64>>

Trading volume

volume24_hr: Option<Value>

24-hour trading volume (for crypto)

volume_all_currencies: Option<Value>

Volume across all currencies (for crypto)

yield_value: Option<F::Value<f64>>

Yield (for bonds/funds)

ytd_return: Option<Value>

Year-to-date return

Implementations

Source

impl SummaryDetail<Both>

pub fn into_raw(self) -> SummaryDetail<Raw>

Convert into a Raw view, extracting .raw from each FormattedValue field.

pub fn as_raw(&self) -> SummaryDetail<Raw>

Clone and convert into a Raw view.

pub fn into_pretty(self) -> SummaryDetail<Pretty>

Convert into a Pretty view, extracting .fmt from each FormattedValue field.

pub fn as_pretty(&self) -> SummaryDetail<Pretty>

Clone and convert into a Pretty view.