#[non_exhaustive]pub enum AlertCondition {
CrossesAbove(f64),
CrossesBelow(f64),
PriceAbove(f64),
PriceBelow(f64),
PercentChangeAbove(f64),
PercentChangeBelow(f64),
VolumeAbove(i64),
}Expand description
A predicate over incoming price ticks.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CrossesAbove(f64)
Price moved from at-or-below the threshold to above it.
CrossesBelow(f64)
Price moved from at-or-above the threshold to below it.
PriceAbove(f64)
Price is above the threshold (fires on the first matching tick).
PriceBelow(f64)
Price is below the threshold (fires on the first matching tick).
PercentChangeAbove(f64)
Percent change from the previous close is at or above the threshold.
PercentChangeBelow(f64)
Percent change from the previous close is at or below the threshold.
VolumeAbove(i64)
Day volume is at or above the threshold.
Implementations