#[non_exhaustive]pub struct Greeks {
pub delta: Option<f64>,
pub gamma: Option<f64>,
pub theta: Option<f64>,
pub vega: Option<f64>,
}Expand description
Option greeks for a contract.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.delta: Option<f64>Rate of change of price with respect to the underlying.
gamma: Option<f64>Rate of change of delta with respect to the underlying.
theta: Option<f64>Rate of change of price with respect to time.
vega: Option<f64>Rate of change of price with respect to volatility.
Implementations