pub struct NewsStreamBuilder { /* private fields */ }Expand description
Builder for creating a NewsStream with custom configuration.
Implementations
Sourceimpl NewsStreamBuilder
impl NewsStreamBuilder
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new builder with no sources and the default 5-minute poll interval.
Sourcepub fn sources(self, sources: impl IntoIterator<Item = FeedSource>) -> Self
pub fn sources(self, sources: impl IntoIterator<Item = FeedSource>) -> Self
Add sources to subscribe to.
Sourcepub fn poll_interval(self, interval: Duration) -> Self
pub fn poll_interval(self, interval: Duration) -> Self
Set the interval between polls of all subscribed sources (default: 5 minutes).
Sourcepub async fn build(self) -> NewsStream
pub async fn build(self) -> NewsStream
Start the news stream.