#[non_exhaustive]pub struct BatchSparksResponse {
pub sparks: HashMap<String, Spark>,
pub errors: HashMap<String, String>,
}Expand description
Response containing spark data for multiple symbols.
Spark data is optimized for sparkline rendering with only close prices. Unlike charts, spark data is fetched in a single batch request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sparks: HashMap<String, Spark>Successfully fetched data, keyed by symbol
errors: HashMap<String, String>Symbols that failed to fetch, with error messages
Implementations
Sourceimpl BatchSparksResponse
impl BatchSparksResponse
Sourcepub fn success_count(&self) -> usize
pub fn success_count(&self) -> usize
Number of successfully fetched items
Sourcepub fn error_count(&self) -> usize
pub fn error_count(&self) -> usize
Number of failed symbols
Sourcepub fn all_successful(&self) -> bool
pub fn all_successful(&self) -> bool
Check if all symbols were successful