#[non_exhaustive]pub struct ChartEvents { /* private fields */ }Expand description
Chart events containing dividends, splits, and capital gains
Events are deserialized from HashMaps, then lazily converted to sorted vectors on first access and cached for subsequent calls.
Implementations
Sourceimpl ChartEvents
impl ChartEvents
Sourcepub fn from_parts(
dividends: Vec<Dividend>,
splits: Vec<Split>,
capital_gains: Vec<CapitalGain>,
) -> Self
pub fn from_parts( dividends: Vec<Dividend>, splits: Vec<Split>, capital_gains: Vec<CapitalGain>, ) -> Self
Build events from public model values.
The only way to construct this outside the crate, for a
CorporateProvider implementation returning
events it fetched itself.
Sourcepub fn to_dividends(&self) -> Vec<Dividend>
pub fn to_dividends(&self) -> Vec<Dividend>
Get sorted list of dividends (cached after first call)
Sourcepub fn to_capital_gains(&self) -> Vec<CapitalGain>
pub fn to_capital_gains(&self) -> Vec<CapitalGain>
Get sorted list of capital gains (cached after first call)