#[non_exhaustive]pub struct EconomicRelease {
pub id: i64,
pub name: Option<String>,
pub press_release: Option<bool>,
pub link: Option<String>,
}Expand description
A publication that releases economic series on a schedule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: i64Release identifier.
name: Option<String>Release name (e.g. "Employment Situation").
press_release: Option<bool>Whether the release is accompanied by a press release.
link: Option<String>Link to the release on the publisher’s site.