#[non_exhaustive]pub struct EdgarSubmissions {Show 15 fields
pub cik: Option<String>,
pub name: Option<String>,
pub entity_type: Option<String>,
pub sic: Option<String>,
pub sic_description: Option<String>,
pub tickers: Vec<String>,
pub exchanges: Vec<String>,
pub state_of_incorporation: Option<String>,
pub fiscal_year_end: Option<String>,
pub ein: Option<String>,
pub website: Option<String>,
pub category: Option<String>,
pub insider_transaction_for_owner_exists: Option<u8>,
pub insider_transaction_for_issuer_exists: Option<u8>,
pub filings: Option<EdgarFilings>,
}Expand description
Full submissions response for a company from SEC EDGAR.
Contains company metadata and filing history. The filings field holds
the most recent ~1000 filings inline, with links to older history files.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cik: Option<String>CIK number (as string)
name: Option<String>Company name
entity_type: Option<String>Entity type (e.g., “operating”)
sic: Option<String>Standard Industrial Classification code
sic_description: Option<String>SIC description
tickers: Vec<String>Ticker symbols associated with this entity
exchanges: Vec<String>Stock exchanges
state_of_incorporation: Option<String>State of incorporation
fiscal_year_end: Option<String>Fiscal year end (MMDD format, e.g., “0930” for September 30)
ein: Option<String>Employer Identification Number
website: Option<String>Company website (often empty in SEC data)
category: Option<String>Filer category (e.g., “Large accelerated filer”)
insider_transaction_for_owner_exists: Option<u8>Whether insider transaction data exists for this entity as owner (0 or 1)
insider_transaction_for_issuer_exists: Option<u8>Whether insider transaction data exists for this entity as issuer (0 or 1)
filings: Option<EdgarFilings>Filing history