#[non_exhaustive]pub struct PriceTargetSummary {
pub symbol: Option<String>,
pub last_month_count: Option<i64>,
pub last_month_avg: Option<f64>,
pub last_quarter_count: Option<i64>,
pub last_quarter_avg: Option<f64>,
pub last_year_count: Option<i64>,
pub last_year_avg: Option<f64>,
pub all_time_count: Option<i64>,
pub all_time_avg: Option<f64>,
}Expand description
Price-target activity over trailing windows: how many targets were published and their average, per window.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.symbol: Option<String>Ticker symbol.
last_month_count: Option<i64>Number of price targets published in the last month.
last_month_avg: Option<f64>Average price target published in the last month.
last_quarter_count: Option<i64>Number of price targets published in the last quarter.
last_quarter_avg: Option<f64>Average price target published in the last quarter.
last_year_count: Option<i64>Number of price targets published in the last year.
last_year_avg: Option<f64>Average price target published in the last year.
all_time_count: Option<i64>Number of price targets published all time.
all_time_avg: Option<f64>Average price target published all time.