pub struct ProvidersBuilder { /* private fields */ }Expand description
Builder for Providers.
Implementations
Sourceimpl ProvidersBuilder
impl ProvidersBuilder
Sourcepub fn fetch(self, mode: Fetch) -> Self
pub fn fetch(self, mode: Fetch) -> Self
Configure how providers are queried. Default: Sequential.
Use Fetch::Sequential or Fetch::Parallel.
Sourcepub fn route(self, cap: Capability, providers: &[Provider]) -> Self
pub fn route(self, cap: Capability, providers: &[Provider]) -> Self
Route a capability to a specific provider priority list.
Providers referenced in the route are automatically added to the initialisation list if not already present. If omitted for a capability, Yahoo is used as default.