#[non_exhaustive]pub struct SectorPerformanceHistory {
pub date: Option<String>,
pub sectors: Vec<SectorPerformance>,
}Expand description
One day of aggregate performance across every sector and exchange.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.date: Option<String>Date (YYYY-MM-DD).
sectors: Vec<SectorPerformance>Per-sector percentage change on that date, one entry per (sector, exchange) pair.