pub struct CryptoCoin { /* private fields */ }Expand description
A cryptocurrency coin backed by configured data providers.
Created via Providers::crypto.
Implementations
Sourceimpl CryptoCoin
impl CryptoCoin
Sourceimpl CryptoCoin
impl CryptoCoin
Sourcepub async fn quote(&self, vs_currency: &str) -> Result<CryptoQuote>
pub async fn quote(&self, vs_currency: &str) -> Result<CryptoQuote>
Fetch the current quote for this coin priced in vs_currency (e.g., "usd").
Sourcepub async fn chart(
&self,
vs_currency: &str,
interval: Interval,
range: TimeRange,
) -> Result<Chart>
pub async fn chart( &self, vs_currency: &str, interval: Interval, range: TimeRange, ) -> Result<Chart>
Fetch historical OHLCV candles for this coin priced in vs_currency.
Unlike quote (which uses the coin id, e.g.
"bitcoin"), the CHART route is symbol-based, so the chart symbol is
built as "{ID}-{VS}" uppercased (e.g. "BTC-USD"). This resolves on
the default Yahoo route only when the handle’s id is the coin’s ticker
(providers.crypto("BTC")); coins identified by a CoinGecko id should
route Capability::CHART to a crypto-aware provider.
Sourcepub async fn history(
&self,
vs_currency: &str,
range: TimeRange,
) -> Result<Chart>
pub async fn history( &self, vs_currency: &str, range: TimeRange, ) -> Result<Chart>
Fetch historical candles over range at a sensible default interval
(TimeRange::default_interval).
Sourcepub async fn indicators(
&self,
vs_currency: &str,
interval: Interval,
range: TimeRange,
) -> Result<IndicatorsSummary>
pub async fn indicators( &self, vs_currency: &str, interval: Interval, range: TimeRange, ) -> Result<IndicatorsSummary>
Compute all technical indicators from this coin’s chart data (priced in
vs_currency).