Non-symbol-specific operations (search, lookup, screeners, market data, etc.). Non-symbol-specific Yahoo Finance operations
This module provides functions for operations that don’t require a specific stock symbol, such as searching for symbols and fetching screener data.
Structs
- Analyst
Estimate - An analyst estimate entry (revenue, EBITDA, EPS forecasts).
- Analyst
Recommendation - An analyst stock recommendation (buy/hold/sell counts).
- Earnings
Calendar Entry - An upcoming earnings calendar entry.
- Insider
Transaction - An insider trading transaction record.
- IpoCalendar
Entry - An upcoming IPO calendar entry.
- Lookup
Options - Lookup configuration options
- Search
Options - Search configuration options
Enums
- Lookup
Type - Asset types available for lookup
- Period
- Time period for analyst estimates.
Functions
- analyst_
estimates - Fetch analyst estimates for a symbol.
- analyst_
recommendations - Fetch analyst stock recommendations for a symbol.
- currencies
- Get list of available currencies
- custom_
screener - Execute a custom screener query
- earnings_
calendar - Fetch the upcoming earnings calendar (market-wide, not symbol-filtered).
- earnings_
transcript - Get earnings transcript for a symbol
- earnings_
transcripts - Get all earnings transcripts for a symbol
- exchanges
- Get list of supported exchanges
- fear_
and_ greed - Fetch the current CNN Fear & Greed Index from Alternative.me.
- hours
- Get market hours/status
- indices
- Get world market indices quotes
- industry
- Fetch detailed industry data from Yahoo Finance
- insider_
trading - Fetch insider trading transactions for a symbol.
- ipo_
calendar - Fetch the upcoming IPO calendar (market-wide, not symbol-filtered).
- lookup
- Look up symbols by type (equity, ETF, mutual fund, index, future, currency, cryptocurrency)
- market_
summary - Get market summary
- news
- Get general market news
- screener
- Fetch data from a predefined Yahoo Finance screener
- search
- Search for stock symbols and companies
- sector
- Fetch detailed sector data from Yahoo Finance
- symbol_
sentiment - Fetch sentiment analysis for a symbol based on recent Polygon.io news.
- trending
- Get trending tickers for a region