Indicators summary module.
Provides the IndicatorsSummary type which calculates and returns the latest
values for all 52+ technical indicators at once.
This module reuses the main indicator implementations and extracts the last value, ensuring consistency and eliminating code duplication.
Structs
- Aroon
Data - Aroon indicator data
- Bollinger
Bands Data - Bollinger Bands data
- Bull
Bear Power Data - Bull Bear Power indicator data
- Donchian
Channels Data - Donchian Channels data
- Elder
RayData - Elder Ray Index data
- Ichimoku
Data - Ichimoku Cloud data
- Indicators
Summary - Summary of all calculated technical indicators
- Keltner
Channels Data - Keltner Channels data
- Macd
Data - MACD indicator data
- Stochastic
Data - Stochastic Oscillator data
- Super
Trend Data - SuperTrend indicator data