#[non_exhaustive]pub struct FactConcept {
pub label: Option<String>,
pub description: Option<String>,
pub units: HashMap<String, Vec<FactUnit>>,
}Expand description
A single XBRL concept (e.g., “Revenue”) with all reported values.
Values are organized by unit of measure (e.g., “USD”, “shares”, “pure”).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.label: Option<String>Human-readable label
description: Option<String>Description of this concept
units: HashMap<String, Vec<FactUnit>>Values organized by unit type (e.g., “USD” -> vec of data points)
Implementations
Sourceimpl FactConcept
impl FactConcept
Sourcepub fn to_dataframe_for_unit(
&self,
unit: &str,
) -> PolarsResult<Option<DataFrame>>
pub fn to_dataframe_for_unit( &self, unit: &str, ) -> PolarsResult<Option<DataFrame>>
Convert all data points from a specific unit to a polars DataFrame.
Arguments
unit- The unit of measure (e.g., “USD”, “shares”, “pure”)
Example
if let Some(revenue) = facts.get_us_gaap_fact("Revenue") {
// Convert USD revenue data to DataFrame
if let Some(df) = revenue.to_dataframe_for_unit("USD")? {
println!("Revenue in USD: {:?}", df);
}
}Sourcepub fn to_dataframe(&self) -> PolarsResult<DataFrame>
pub fn to_dataframe(&self) -> PolarsResult<DataFrame>
Convert all data points from all units to a single polars DataFrame.
Adds a “unit” column to distinguish between different units of measure.
Example
if let Some(revenue) = facts.get_us_gaap_fact("Revenue") {
let df = revenue.to_dataframe()?;
println!("All revenue data: {:?}", df);
}Trait Implementations
Sourceimpl Clone for FactConcept
impl Clone for FactConcept
Sourcefn clone(&self) -> FactConcept
fn clone(&self) -> FactConcept
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FactConcept
impl Debug for FactConcept
Sourceimpl<'de> Deserialize<'de> for FactConcept
impl<'de> Deserialize<'de> for FactConcept
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more