pub struct Providers { /* private fields */ }Expand description
Central provider configuration shared across query handles.
Build once with Providers::builder, then create lightweight
Ticker handles that share the same underlying
provider connections and authentication.
Example
use finance_query::{Providers, Provider, Fetch, Capability};
let providers = Providers::builder()
.route(Capability::QUOTE, &[Provider::Yahoo])
.fetch(Fetch::Sequential)
.build().await?;
// All Ticker handles share the same Arc<ProviderSet>
let aapl = providers.ticker("AAPL").build().await?;
let nvda = providers.ticker("NVDA").logo().build().await?;Implementations
Sourceimpl Providers
impl Providers
Sourcepub fn builder() -> ProvidersBuilder
pub fn builder() -> ProvidersBuilder
Create a builder for configuring providers.
Sourcepub fn ticker(&self, symbol: impl Into<String>) -> TickerBuilder
pub fn ticker(&self, symbol: impl Into<String>) -> TickerBuilder
Create a TickerBuilder pre-wired to this provider set.
The returned builder accepts the same optional configuration as
Ticker::builder (.cache(), .logo(),
.format()) before calling .build().
Sourcepub fn tickers<S, I>(&self, symbols: I) -> TickersBuilder
pub fn tickers<S, I>(&self, symbols: I) -> TickersBuilder
Create a TickersBuilder pre-wired to this provider set.
The returned builder accepts the same optional configuration as
Tickers::builder (.cache(),
.max_concurrency(), .logo(), .format()) before calling .build().
Sourcepub fn crypto(&self, id: impl Into<String>) -> CryptoCoin
pub fn crypto(&self, id: impl Into<String>) -> CryptoCoin
Create a CryptoCoin handle backed by this provider set.
Sourcepub fn forex(&self, from: impl Into<String>, to: impl Into<String>) -> ForexPair
pub fn forex(&self, from: impl Into<String>, to: impl Into<String>) -> ForexPair
Create a ForexPair handle backed by this provider set.
Sourcepub fn economic(&self, series_id: impl Into<String>) -> EconomicIndicator
pub fn economic(&self, series_id: impl Into<String>) -> EconomicIndicator
Create an EconomicIndicator handle backed by this provider set.
Sourcepub fn index(&self, symbol: impl Into<String>) -> Index
pub fn index(&self, symbol: impl Into<String>) -> Index
Create an Index handle backed by this provider set.
Sourcepub fn futures(&self, symbol: impl Into<String>) -> FuturesContract
pub fn futures(&self, symbol: impl Into<String>) -> FuturesContract
Create a FuturesContract handle backed by this provider set.